Summary: Library of functions for manipulating TIFF format image files
Name: libtiff
Version: 3.9.2
Release: 2
License: BSD
Group: System Environment/Libraries
URL: http://www.libtiff.org/

Source0: ftp://ftp.remotesensing.org/pub/%{name}/tiff-%{version}.tar.gz
Source1: tiffconf.h
Patch0: %{name}-%{version}-mantypo.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: make, libjpeg-devel, zlib-devel, jbigkit-devel
Requires: libjpeg, zlib, jbigkit-libs

%description
The libtiff package contains a library of functions for manipulating
TIFF (Tagged Image File Format) image format files.  TIFF is a widely
used file format for bitmapped images.  TIFF files usually end in the
.tif extension and they are often quite large.

The libtiff package should be installed if you need to manipulate TIFF
format image files.

The library is available as 32-bit and 64-bit.


%package devel
Summary: Development tools for programs which will use the libtiff library
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: jbigkit-devel

%description devel
This package contains the header files and documentation necessary for
developing programs which will manipulate TIFF format image files
using the libtiff library.

If you need to develop programs which will manipulate TIFF format
image files, you should install this package.  You'll also need to
install the libtiff package.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc -q64" or "gcc -maix64".


%prep
export PATH=/opt/freeware/bin:$PATH
%setup -q -n tiff-%{version}
%patch0


%build
# setup environment for 32-bit and 64-bit builds
export AR="ar -X32_64"
export NM="nm -X32_64"

# first build the 64-bit version
export CC="xlc -q64"
export CXX="xlC -q64"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --enable-shared --enable-static
gmake %{?_smp_mflags}

cp libtiff/.libs/libtiff.so.3 .
cp libtiff/.libs/libtiffxx.so.3 .
cp libtiff/tiffconf.h tiffconf-ppc64.h
gmake distclean

# now build the 32-bit version
export CC="xlc"
export CXX="xlC"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --enable-shared --enable-static
gmake %{?_smp_mflags}

cp libtiff/tiffconf.h tiffconf-ppc32.h

# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
${AR} -q libtiff/.libs/libtiff.a ./libtiff.so.3
${AR} -q libtiff/.libs/libtiffxx.a ./libtiffxx.so.3

# add AIX Toolbox compatibility members for compatibility with older apps
# (make sure they're set for LOADONLY with 'strip -e')
mv libtiff.so.3 shr.o
/usr/bin/strip -X64 -e shr.o
${AR} -q libtiff/.libs/libtiff.a ./shr.o
cp libtiff/.libs/libtiff.so.3 shr.o
/usr/bin/strip -X32 -e shr.o
${AR} -q libtiff/.libs/libtiff.a ./shr.o


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}
gmake DESTDIR=${RPM_BUILD_ROOT} install

cp tiffconf-ppc??.h $RPM_BUILD_ROOT%{_includedir}/
cp %{SOURCE1} $RPM_BUILD_ROOT%{_includedir}/
chmod 644 $RPM_BUILD_ROOT%{_includedir}/*.h

/usr/bin/strip ${RPM_BUILD_ROOT}%{_bindir}/* || :

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%doc COPYRIGHT README RELEASE-DATE VERSION
%{_bindir}/*
%{_libdir}/*.a
%{_mandir}/man1/*
/usr/bin/*
/usr/lib/*.a


%files devel
%defattr(-,root,system,-)
%doc TODO ChangeLog html
%{_includedir}/*
%{_libdir}/*.la
%{_mandir}/man3/*
/usr/include/*
/usr/lib/*.la


%changelog
* Tue Jan 19 2010 Michael Perzl <michael@perzl.org> - 3.9.2-2
- fixed a spec file dependency

* Thu Nov 05 2009 Michael Perzl <michael@perzl.org> - 3.9.2-1
- updated to version 3.9.2
- fixed AIX Toolbox compatibility issues

* Mon Aug 31 2009 Michael Perzl <michael@perzl.org> - 3.9.1-1
- updated to version 3.9.1

* Wed Aug 26 2009 Michael Perzl <michael@perzl.org> - 3.9.0-1
- updated to version 3.9.0

* Sat Mar 22 2008 Michael Perzl <michael@perzl.org> - 3.8.2-1
- first version for AIX V5.1 and higher
